# [2.5.1](https://github.com/seriaati/enka-py/compare/v2.5.0..v2.5.1) - 2025-04-23

## Features

- **(deps)** Add deprecated - ([5b4e8ff](https://github.com/seriaati/enka-py/commit/5b4e8ff531488beb7305290ce8052579a6821193))
- Add title and namecard fields - ([89d9463](https://github.com/seriaati/enka-py/commit/89d9463c8c3c77396606762ae44897bcb8445da9))

## Miscellaneous Chores

- **(deps)** lock file maintenance ([#102](https://github.com/seriaati/enka-py/issues/102)) - ([eebff9c](https://github.com/seriaati/enka-py/commit/eebff9c6bc9b230aa7e1ef021b83767f78faaac2))

